"""
Extracts and bakes global scale into global variables
"""

import maya.cmds as cmds
from rigging_framework import global_variables as gvar
from rigging_framework.templates.common.utilities import utils as utils

# getting parameters
args = gvar.get_step_arguments()
global_scale_obj = args["global_scale_obj"]
global_scale_attr = args["global_scale_attr"]
main_joint = args["main_joint"]

# extract global scale from the rig and save it to global variables
gvar.set("global_scale", cmds.getAttr("{}.global_scale".format(global_scale_obj)))
gvar.set("joint_radius", cmds.getAttr("{}.radius".format(main_joint)))

for scale_attr in "sx", "sy", "sz":
    cmds.setAttr("{0}.{1}".format(global_scale_obj, scale_attr), lock=False)
    utils.disconnect_attr("{0}.{1}".format(global_scale_obj, scale_attr))

# pivots cannot be frozen off...
cmds.parent("Pivots_Grp", world=True)

# freeze scale on global scale object
cmds.makeIdentity(global_scale_obj, scale=True, apply=True)

# unparent all the children
for child in cmds.listRelatives(global_scale_obj, children=True, shapes=False):
    try:
        cmds.parent(child, world=True)
    except RuntimeError:
        cmds.warning("Object already in the world space {}".format(child))

cmds.delete(global_scale_obj)
