"""
Cleans up bound skeleton, removes segment scale compensation
"""

import maya.cmds as cmds

from rigging_framework.templates.common.utilities import joints
from rigging_framework import global_variables as gvar

# getting parameters
args = gvar.get_step_arguments()
root_joint = args["root_joint"]

skip_joints = None
if "skip_joints" in args:
    skip_joints = args["skip_joints"]

# getting joints to skip and their children:
joints_to_skip = []

if skip_joints:
    skip_joints = skip_joints.split(',')

    for skip_joint in skip_joints:
        joints_to_skip.append(skip_joint)
        joints_to_skip.extend(cmds.listRelatives(skip_joint, allDescendents=True))

joints_to_skip = list(set(joints_to_skip))

# get all the joints in the skinned skeleton:
all_joints = [root_joint] + cmds.listRelatives(root_joint, allDescendents=True)
all_joints = [x for x in all_joints if cmds.nodeType(x) == "joint"]

# skipping joints to skip and their children
all_joints = list(set(all_joints) - set(joints_to_skip))

# disable segment scale compensation on the skinned skeleton
joints.set_segment_scale_enabled(all_joints, False)

# x-forming all the skinning joints - removing joint orients (bound skeleton):
joints.xform_joints(all_joints)


