# cleans up the rig

import maya.cmds as cmds
from rigging_framework import global_variables as gvar

# getting parameters
args = gvar.get_step_arguments()
geometry_grp = args["geometry_folder"]
skeleton_grp = args["skeleton_folder"]
pivots_grp = args["pivots_folder"]

do_not_touch_grp = gvar.get("Do_Not_Touch_Grp")
global_ctrl = gvar.get("Global_Ctrl")

# deleting pivot group
cmds.delete(pivots_grp)

cmds.setAttr(do_not_touch_grp + ".visibility", 0)

all_controls = cmds.ls("*_Ctrl")

for control in all_controls:
    cmds.setAttr(control + ".visibility", lock=True, keyable=False)
    for axis in "xyz":
        cmds.setAttr(control + ".s{0}".format(axis), lock=True, keyable=False)

all_groups = cmds.ls("*_Grp")
attributes = ("tx", "ty", "tz", "rx", "ry", "rz", "sx", "sy", "sz")
for grp in all_groups:
    cmds.setAttr(grp + ".visibility", lock=True, keyable=False)
    for attr in attributes:
        cmds.setAttr("{0}.{1}".format(grp, attr), lock=True, keyable=False)
        cmds.setAttr("{0}.{1}".format(grp, attr), lock=True, keyable=False)

# geometry layer
all_geometries = cmds.listRelatives(geometry_grp, allDescendents=True, type="transform")
cmds.select(all_geometries)
geo_layer = cmds.createDisplayLayer(name="Geometry_Layer", noRecurse=True)
cmds.setAttr("{0}.displayType".format(geo_layer), 2)

# skeleton layer
all_skeleton_items = cmds.listRelatives(skeleton_grp, allDescendents=True)
all_skeleton_items = [x for x in all_skeleton_items if cmds.nodeType(x) in ("joint", "transform")]
cmds.select(all_skeleton_items)
skeleton_layer = cmds.createDisplayLayer(name="Skeleton_Layer", noRecurse=True)
cmds.setAttr("{0}.visibility".format(skeleton_layer), 0)


# controls layer
cmds.select(all_controls)
controls_layer = cmds.createDisplayLayer(name="Controls_Layer", noRecurse=True)
