import maya.cmds as cmds

import rigging_framework.templates.common.utilities.transform
from rigging_framework.templates.common.utilities import joints
from rigging_framework.templates.common.utilities import utils
from rigging_framework import global_variables as gvar

# getting parameters
args = gvar.get_step_arguments()
root_joint = args["root_joint"]

skip_joints = None
if "skip_joints" in args:
    skip_joints = args["skip_joints"]

do_not_touch_grp = gvar.get("Do_Not_Touch_Grp")
skeleton_grp = gvar.get("Skeleton_Grp")

# if skip joint list is there extract the list from string with commas:
if skip_joints:
    skip_joints = skip_joints.split(',')

# duplicate the skeleton - create rig skeleton with suffix RIG
rig_reference = utils.duplicate_rename(rigging_framework.templates.common.utilities.transform.get_parent(root_joint), suffix="_RIG")

# delete skip joints that were duplicated:
if skip_joints:
    for skip_joint in skip_joints:
        cmds.delete(skip_joint + "_RIG")

rig_root_joint = root_joint + "_RIG"
rig_skeleton = [rig_reference] + cmds.listRelatives(rig_reference, allDescendents=True)

# remove all the twister joints (if necessary -> for bipeds):
for rig_element in rig_skeleton:
    if "Twister" in rig_element and cmds.nodeType(rig_element) == "joint":
        cmds.delete(rig_element)

# get all rig skeleton joints:
all_rig_joints = [rig_root_joint] + cmds.listRelatives(rig_root_joint, allDescendents=True)

# disable segment scale compensation on the rig skeleton
joints.set_segment_scale_enabled(all_rig_joints, False)

rig_skeleton_grp = cmds.createNode("transform", name="Rig_Skeleton_Grp")
cmds.parent(rig_skeleton_grp, do_not_touch_grp)
cmds.parent(rig_reference, rig_skeleton_grp)
cmds.connectAttr(skeleton_grp + ".s", rig_skeleton_grp + ".s")

gvar.set("Rig_Skeleton_Grp", rig_skeleton_grp)
