"""
makes a global control for the rig
makes a group for all controls that will be scaling with the rig  Global Control
"""

import maya.cmds as cmds

from rigging_framework import global_variables as gvar
from rigging_framework.templates.common.utilities import transform as trans_mod
from rigging_framework.templates.common.utilities import utils as utils
from rigging_framework.templates.common.utilities import rig_controls as rig_ctrls

# gather data from global variables:
global_scale = gvar.get("global_scale")
grp_rig_ctrls = gvar.get('Controls_Grp')
grp_rig_joints = gvar.get('Skeleton_Grp')

# make global control:
global_ctrl = rig_ctrls.make_control(control_type="circle_Y", size=6 * global_scale, name="Global_Ctrl", color="purple")
utils.match_sec_to_first("Reference", global_ctrl)
trans_mod.make_space_for(global_ctrl, "Grp", parent=grp_rig_ctrls)

cmds.addAttr(global_ctrl, longName="global_scale", defaultValue=1, minValue=0.01, maxValue=1000, keyable=True)
cmds.connectAttr(global_ctrl+".global_scale", global_ctrl+".sx")
cmds.connectAttr(global_ctrl+".global_scale", global_ctrl+".sy")
cmds.connectAttr(global_ctrl+".global_scale", global_ctrl+".sz")

cmds.addAttr(global_ctrl, longName="extra_controls", attributeType="enum", enumName="Off:On", keyable=True)

# scale constrain rig joints to global control:
cmds.scaleConstraint(global_ctrl, grp_rig_joints)

# store global control and scaling controls in global variables
gvar.set('Global_Ctrl', global_ctrl)
