import maya.cmds as cmds


# lock and hide scale on all controls
all_controls = cmds.ls("*_Ctrl")

for control in all_controls:
    cmds.setAttr(control + ".visibility", lock=True, keyable=False)
    for axis in "xyz":
        cmds.setAttr(control + ".s{0}".format(axis), lock=True, keyable=False)

# lock all groups
all_groups = cmds.ls("*_Grp")
attributes = ("tx", "ty", "tz", "rx", "ry", "rz", "sx", "sy", "sz")
for grp in all_groups:
    cmds.setAttr(grp + ".visibility", lock=True, keyable=False)
    for attr in attributes:
        cmds.setAttr("{0}.{1}".format(grp, attr), lock=True, keyable=False)
        cmds.setAttr("{0}.{1}".format(grp, attr), lock=True, keyable=False)

# geometry layer
if cmds.objExists("Geometry_Grp"):
    all_geometries = cmds.listRelatives("Geometry_Grp", allDescendents=True, type="transform")
    cmds.select(all_geometries)
    geo_layer = cmds.createDisplayLayer(name="Geometry_Layer", noRecurse=True)
    cmds.setAttr("{0}.displayType".format(geo_layer), 2)

# skeleton layer
if cmds.objExists("Skeleton_Grp"):
    all_skeleton_items = cmds.listRelatives("Skeleton_Grp", allDescendents=True)
    all_skeleton_items = [x for x in all_skeleton_items if cmds.nodeType(x) in ("joint", "transform")]
    cmds.select(all_skeleton_items)
    skeleton_layer = cmds.createDisplayLayer(name="Skeleton_Layer", noRecurse=True)
    # cmds.setAttr("{0}.visibility".format(skeleton_layer), 0)

# controls layer
cmds.select(all_controls)
controls_layer = cmds.createDisplayLayer(name="Controls_Layer", noRecurse=True)

# remove reduntant selection sets:
cmds.delete(cmds.ls("*_Ik_System", type="objectSet"))
cmds.delete(cmds.ls("*Angle_Between_Set", type="objectSet"))

# remove foot pivots group if it exists:
if cmds.objExists("Foot_Pivots_Grp"):
    cmds.delete("Foot_Pivots_Grp")

# remove turtle nodes:
turtle_nodes = cmds.ls("Turtle*")
for turtle_node in turtle_nodes:
    cmds.lockNode(turtle_node, lock=False)

cmds.delete(turtle_nodes)

# hide local rotation axes for all the joints:
for jnt in cmds.ls(type="joint"):
    cmds.setAttr(jnt + ".displayLocalAxis", False)

# create selection set for the controls
cmds.sets(all_controls, name="Set_All_Controls")

# create selection sets for finger controls:
for side in "Left", "Right":
    thumb_ctrls = cmds.ls(f"{side}_Thumb*Ctrl")
    index_ctrls = cmds.ls(f"{side}_Index*Ctrl")
    middle_ctrls = cmds.ls(f"{side}_Middle*Ctrl")
    ring_ctrls = cmds.ls(f"{side}_Ring*Ctrl")
    pinky_ctrls = cmds.ls(f"{side}_Pinky*Ctrl")
    cmds.sets(thumb_ctrls + index_ctrls + middle_ctrls + ring_ctrls + pinky_ctrls, name=f"Set_{side}_Hand_Finger")
