import json
import maya.cmds as cmds
import rigging_framework.templates.common.utilities.transform as trans_mod


all_controls = [x for x in cmds.ls("*_Ctrl") if not x.startswith("Name__")]

main_grp = cmds.createNode("transform", name="PoseInfo_Grp")

do_not_touch = "Do_Not_Touch"

if cmds.objExists(do_not_touch):
    cmds.parent(main_grp, do_not_touch)

for ctrl in all_controls:
    # create an offset group for each control
    offset = cmds.createNode("transform", name="{}_PoseSwitch_Grp".format(ctrl))
    bind = cmds.createNode("transform", name="{}_Bind_Grp".format(ctrl))
    tpose = cmds.createNode("transform", name="{}_TPose_Grp".format(ctrl))

    cmds.matchTransform(offset, ctrl)
    ctrl_parent = cmds.listRelatives(ctrl, parent=True)[0]
    cmds.parent(offset, ctrl_parent)
    cmds.parent(ctrl, offset)

    trans_mod.copy_transform(offset, bind)
    trans_mod.copy_transform(offset, tpose)

    cmds.parent(bind, tpose, main_grp)


cwd = os.path.dirname(os.path.realpath(__file__))

configs_file = os.path.join(cwd, r"templates\humanoid_rig\data\DefaultTPose.json")

with open(configs_file, "r") as f_obj:
    offsets_data = json.load(f_obj)

for offset in offsets_data:
    trans_mod.set_transform(offset, offsets_data[offset])
    ctrl = cmds.listRelatives(offset, children=True)[0]
    trans_mod.zero_out_objects([ctrl])
    tpose_node = "{}_TPose_Grp".format(ctrl)
    trans_mod.copy_transform(offset, tpose_node)  # this will store values in the rig
