import rigging_framework.templates.common.modules.fk_chain
import rigging_framework.templates.common.utilities.constraints as cnst


def build(fk_toe_base_bone, fk_toes_end_bone,
          name_or_none=None, add_prefix="", add_suffix="",
          replace_in_name=(("FK_", ""), ("_Jnt", "")),
          scale=1, virtual_constraints=False):
          
    """
    Builds a simple fk foot rig base on fk joints
    
    For now has certain hardcoded features:
    removes substrings: FK_ and _Jnt in joint name
    adds suffix: FK_Ctrl
    
    :param str fk_toe_base_bone: FK toe base bone
    :param str fk_toes_end_bone: FK toes end bone
    :param str name_or_none: Name of the module - otherwise it will generate automatically
    :param str add_prefix: Prefix for the control names
    :param str add_suffix: Suffix for the control names
    :param tuple(str,str) replace_in_name: Replace substring in control name
    :param float scale: scale of controls 
    :param bool virtual_constraints: Build constraints or not (if True)
    :return dict:
        result = {"Module_Group": name of the main module group,
                  "Controls": list of controls,
                  "Control_Groups": list of control groups
    """
    
    if not virtual_constraints:
        cnst.initialize_constraints()

    fk_chain_data = rigging_framework.templates.common.modules.fk_chain.build([fk_toe_base_bone, fk_toes_end_bone],
                                                                              name_or_none=name_or_none,
                                                                              add_prefix=add_prefix,
                                                                              add_suffix=add_suffix,
                                                                              replace_in_name=replace_in_name,
                                                                              scale=scale, point_constraint=True,
                                                                              orient_constraint=True,
                                                                              scale_constraint=False,
                                                                              virtual_constraints=virtual_constraints)

    result = {"Module_Group": fk_chain_data["Module_Group"],
              "Controls": fk_chain_data["Controls"],
              "Control_Groups":  fk_chain_data["Control_Groups"]}

    return result
