import maya.cmds as cmds
from collections import OrderedDict

import rigging_framework.templates.common.utilities.transform
from rigging_framework.templates.common.utilities import space_switching

from rigging_framework import global_variables as gvar

global_scale = gvar.get("global_scale")
do_not_touch_grp = gvar.get("Do_Not_Touch_Grp")
gizmos_grp = gvar.get("Gizmos_Grp")
controls_grp = gvar.get("Controls_Grp")
scaling_ctrls_grp = gvar.get("Scaling_Controls_Grp")
global_ctrl = gvar.get("Global_Ctrl")
cog_ctrl = gvar.get("COG_Ctrl")
head_ctrl = gvar.get("Head_Ctrl")

# adds space switching for the rig:

# create world locator:
world_locator = cmds.spaceLocator(name="world_locator")[0]
cmds.parent(world_locator, do_not_touch_grp)

# feet
for side in "Left_Front", "Left_Rear", "Right_Rear", "Right_Front":
    foot_ik_ctrl = gvar.get(f"{side}_IK_Foot_Ctrl")
    foot_ik_ctrl_grp = rigging_framework.templates.common.utilities.transform.get_parent(foot_ik_ctrl)

    space_dictionary = OrderedDict([(global_ctrl, "global_control"), (cog_ctrl, "cog_ctrl"), (world_locator, "world")])

    space_switching.build_space_switching(foot_ik_ctrl, space_dictionary, control_group=foot_ik_ctrl_grp,
                                          attribute_name="parent_space", space_type="default", existing_attribute=False)


# knee pole vectors:
for side in "Left_Front", "Left_Rear", "Right_Rear", "Right_Front":
    foot_ik_ctrl = gvar.get(f"{side}_IK_Foot_Ctrl")

    leg_controls = gvar.get("{0}_Leg_Controls".format(side))
    pole_vector_controls = [x for x in leg_controls if "Knee_IK" in x]

    for pole_vector_control in pole_vector_controls:
        pole_vector_control_grp = rigging_framework.templates.common.utilities.transform.get_parent(pole_vector_control)
        space_dictionary = OrderedDict([(global_ctrl, "global_control"), (cog_ctrl, "cog_ctrl"),
                                        (foot_ik_ctrl, "foot_ik_control"), (world_locator, "world")])

        space_switching.build_space_switching(pole_vector_control, space_dictionary,
                                              control_group=pole_vector_control_grp,
                                              attribute_name="parent_space", space_type="default",
                                              existing_attribute=False, default_index=2)

# head - this one is a bit more complicated cos head also has fk mode, so we need to add the group inbetween...
head_space_switch_grp = cmds.group(head_ctrl, name="{0}_Offset_Grp".format(head_ctrl))

space_dictionary = OrderedDict([(None, "neck_base_control"), (cog_ctrl, "cog_ctrl"),
                                (global_ctrl, "global_control"), (world_locator, "world")])

space_switching.build_space_switching(head_ctrl, space_dictionary, control_group=head_space_switch_grp,
                                      attribute_name="parent_space", space_type="default", existing_attribute=False)
