import maya.cmds as cmds

from rigging_framework import global_variables as gvar
from rigging_framework.templates.humanoid_rig.modules import ikfk_foot_rig


def copy_attr_value(source_attr, target_attr):
    """
    copies attribute from first attribute to the second
    :param source_attr:
    :param target_attr:
    :return:
    """
    cmds.setAttr(target_attr, cmds.getAttr(source_attr))


global_scale = gvar.get("global_scale")
do_not_touch_grp = gvar.get("Do_Not_Touch_Grp")
gizmos_grp = gvar.get("Gizmos_Grp")
controls_grp = gvar.get("Controls_Grp")
scaling_ctrls_grp = gvar.get("Scaling_Controls_Grp")
global_ctrl = gvar.get("Global_Ctrl")
rig_orientation = gvar.get("rig_orientation")


for side in "Left_Front", "Left_Rear", "Right_Rear", "Right_Front":
    foot_ik = gvar.get("{0}_Leg_Main_Node".format(side))

    ik_ankle_bone = "IK_{0}_Ankle_Jnt_RIG".format(side)
    fk_ankle_bone = "FK_{0}_Ankle_Jnt_RIG".format(side)
    toe_base_bone = "{0}_Toebase_Jnt_RIG".format(side)
    toes_end_bone = "{0}_Toes_End_Jnt_RIG".format(side)

    toe_pivot = side + "_Toe_Pivot"
    rear_pivot = side + "_Rear_Pivot"
    out_pivot = side + "_Out_Pivot"
    in_pivot = side + "_In_Pivot"
    ball_pivot = side + "_Ball_Pivot"
    spin_pivot = side + "_Spin_Pivot"

    ikfk_switch_ctrl = gvar.get("{0}_Leg_IKFK_Switch_Ctrl".format(side))

    # build ikfk footrig module
    ikfk_foot_rig_data = ikfk_foot_rig.build(name="{0}_Ik_Foot_Rig".format(side), scale=global_scale,
                                             ikfk_switch_control=ikfk_switch_ctrl, leg_ik=foot_ik,
                                             ikfk_switch_attr="ikfk_blend",
                                             ik_ankle_bone=ik_ankle_bone, fk_ankle_bone=fk_ankle_bone,
                                             toe_base_bone=toe_base_bone, toes_end_bone=toes_end_bone,
                                             toe_pivot=toe_pivot, rear_pivot=rear_pivot, out_pivot=out_pivot,
                                             in_pivot=in_pivot, ball_pivot=ball_pivot, spin_pivot=spin_pivot)

    # add attributes for soft ik and auto shoulder/ knee bend ratios:

    cmds.addAttr(ikfk_foot_rig_data["IK_Foot_Control"], longName="soft_ik", attributeType="float",
                 minValue=0, maxValue=50, keyable=True)
    cmds.connectAttr("{0}.soft_ik".format(ikfk_foot_rig_data["IK_Foot_Control"]), "{0}.soft_ik".format(foot_ik))

    attr_name = "automatic_shoulder"
    if "Rear" in side:
        attr_name = "knee_bend_ratio"

    cmds.addAttr(ikfk_foot_rig_data["Controls"][0], longName=attr_name, attributeType="float",
                 minValue=0, maxValue=1.0, keyable=True)
    copy_attr_value("{0}.{1}".format(foot_ik, attr_name), "{0}.{1}".format(ikfk_foot_rig_data["Controls"][0], attr_name))
    cmds.connectAttr("{0}.{1}".format(ikfk_foot_rig_data["Controls"][0],
                     attr_name), "{0}.{1}".format(foot_ik, attr_name))

    # now put module elements where they need to go:
    cmds.parent(ikfk_foot_rig_data["Module_Group"], do_not_touch_grp)

    # save data to global variables:
    gvar.set("{0}_IKFK_Footrig_Controls".format(side), ikfk_foot_rig_data["Controls"])
    gvar.set(f"{side}_IK_Foot_Ctrl", ikfk_foot_rig_data["IK_Foot_Control"])


# Reorganize footrig groups:
for foot_module in cmds.ls("*Ik_Foot_Rig_Module*"):
    cmds.parent(foot_module, "Controls_Grp")
for foot_top_grp in cmds.ls("*Footrig_Top_Grp*"):
    cmds.setAttr(foot_top_grp + ".v", False)