import maya.cmds as cmds

import rigging_framework.templates.common.utilities.transform
from rigging_framework.templates.quadruped_rig.modules import rear_ikfk_leg
from rigging_framework import global_variables as gvar

global_scale = gvar.get("global_scale")
do_not_touch_grp = gvar.get("Do_Not_Touch_Grp")
gizmos_grp = gvar.get("Gizmos_Grp")
scaling_ctrls_grp = gvar.get("Scaling_Controls_Grp")
global_ctrl = gvar.get("Global_Ctrl")
rig_orientation = gvar.get("rig_orientation")

for side in "Left", "Right":
    rear_ikfk_leg_data = rear_ikfk_leg.build("{}_Rear_Leg".format(side), "{}_Hip_Jnt_RIG".format(side),
                                             "{}_Rear_Upper_Knee_Jnt_RIG".format(side),
                                             "{}_Rear_Lower_Knee_Jnt_RIG".format(side),
                                             "{}_Rear_Ankle_Jnt_RIG".format(side), global_scale,
                                             rig_orientation)

    cmds.parent(rear_ikfk_leg_data["Do_Not_Touch_Grp"], do_not_touch_grp)
    cmds.parent(rear_ikfk_leg_data["Gizmos_Grp"], gizmos_grp)
    cmds.parent(rear_ikfk_leg_data["Controls_Grp"], scaling_ctrls_grp)

    cmds.connectAttr(global_ctrl + ".global_scale", rear_ikfk_leg_data["Main_Node"] + ".global_scale")

    gvar.set("{0}_Rear_Leg_Controls".format(side), rear_ikfk_leg_data["Controls"])
    gvar.set("{0}_Rear_Leg_Main_Node".format(side), rear_ikfk_leg_data["Main_Node"])
    gvar.set("{0}_Rear_Leg_IKFK_Switch_Ctrl".format(side), rear_ikfk_leg_data["IKFK_Switch_Ctrl"])

    # making sure shoulder controls follow chest joint:
    hips_joint = rigging_framework.templates.common.utilities.transform.get_parent("{}_Hip_Jnt_RIG".format(side))
    cmds.parentConstraint(hips_joint, rear_ikfk_leg_data["Controls_Grp"], maintainOffset=True)

cmds.delete('FK_Left_Hip_Jnt_RIG_Module_Group', 'FK_Right_Hip_Jnt_RIG_Module_Group')
