import maya.cmds as cmds

from rigging_framework import global_variables as gvar
from rigging_framework.templates.common.utilities import rig_controls
from rigging_framework.templates.common.utilities import transform as trans_mod
from rigging_framework.templates.common.utilities import constraints

global_scale = gvar.get("global_scale")
do_not_touch_grp = gvar.get("Do_Not_Touch_Grp")
gizmos_grp = gvar.get("Gizmos_Grp")
controls_grp = gvar.get("Controls_Grp")
scaling_ctrls_grp = gvar.get("Scaling_Controls_Grp")
global_ctrl = gvar.get("Global_Ctrl")
rig_orientation = gvar.get("rig_orientation")

# add new attribute extra controls if it doesnt exist:
if not cmds.objExists(global_ctrl + ".extra_controls"):
    cmds.addAttr(global_ctrl, longName="extra_controls", attributeType="enum", enumName="Off:On", keyable=True)

for side in "Left_Front", "Left_Rear", "Right_Rear", "Right_Front":
    for which in "Upper", "Lower":
        knee_rig_jnt = "{0}_{1}_Knee_Jnt_RIG".format(side, which)
        knee_jnt = "{0}_{1}_Knee_Jnt".format(side, which)
        knee_parent = cmds.listRelatives(knee_rig_jnt, parent=True)[0]

        knee_pos = cmds.xform(knee_rig_jnt, query=True, translation=True, worldSpace=True)
        knee_rot = cmds.xform(knee_rig_jnt, query=True, rotation=True, worldSpace=True)

        knee_ctrl = rig_controls.make_control("circle_X", name=knee_jnt + "_Offset_Ctrl", color="teal",
                                              position=knee_pos, rotation=knee_rot,
                                              scale=(global_scale * 0.5, global_scale * 0.5, global_scale * 0.5))

        knee_ctrl_grp = trans_mod.make_space_for(knee_ctrl)
        cmds.connectAttr(global_ctrl + ".extra_controls", knee_ctrl_grp + ".visibility")
        cmds.parent(knee_ctrl_grp, controls_grp)

        cmds.parentConstraint(knee_rig_jnt, knee_ctrl_grp, maintainOffset=True)
        cmds.scaleConstraint(knee_rig_jnt, knee_ctrl_grp, maintainOffset=True)

        constraints.parent_constraint(knee_ctrl, knee_jnt, maintain_offset=True, use_mapping_file=True)
        constraints.scale_constraint(knee_ctrl, knee_jnt, maintain_offset=True, use_mapping_file=True)
